document.addEventListener('DOMContentLoaded', (event) => {
    function getSize(sizeText) {
        let size = parseFloat(sizeText);
        let unit = sizeText.match(/[a-zA-Z]+/)[0];

        switch (unit) {
            case 'KB':
                size = size / 1024; // Convert KB to MB
                break;
            case 'B':
                size = size / (1024 * 1024); // Convert bytes to MB
                break;
            case 'GB':
                size = size * 1024; // Convert GB to MB
                break;
            // No need for a case for MB, as it's already in the correct unit
        }

        return size; // Return size in MB
    }

    const sizeElements = document.querySelectorAll('.size');

    let totalSizeMB = 0;
    sizeElements.forEach(sizeElement => {
        const sizeText = sizeElement.textContent;
        totalSizeMB += getSize(sizeText);
    });

    const totalSizeInGB = totalSizeMB / 1024; // Convert total size to GB
    const totalSpaceGB = 128;
    const percentageUsed = (totalSizeInGB / totalSpaceGB) * 100;

    const textIndicator = document.getElementById('text-indicator');
    const usedIndicator = document.getElementById('used-indicator');

    let currentSize = 0;
    let currentPercentage = 0;

    const interval = setInterval(() => {
        currentSize += totalSizeInGB / 100;
        currentPercentage += percentageUsed / 100;

        if (currentPercentage >= percentageUsed) {
            currentSize = totalSizeInGB;
            currentPercentage = percentageUsed;
            clearInterval(interval);
        }

        textIndicator.textContent = `${currentSize.toFixed(2)} GB of 128 GB`;
        usedIndicator.style.width = `${currentPercentage.toFixed(2)}%`;

    }, 20); // Adjust the duration to match the desired speed of the animation
});



function updateDots() {
    const items = document.querySelectorAll('.item');
    items.forEach(item => {
      const containerWidth = item.offsetWidth;
      const textWidth = item.querySelector('.name').offsetWidth + 10;
      const sizeWidth = item.querySelector('.size').offsetWidth + 10;
      const dotWidth = 10;  // Assume each dot takes up 10px; you'll need to measure this
      const numDots = Math.floor((containerWidth - textWidth - sizeWidth) / dotWidth);
      item.querySelector('.dots').textContent = '.'.repeat(numDots);
      console.log('dots');
    });
  }

  // Run the function initially and whenever the window is resized
  updateDots();
  window.addEventListener('resize', updateDots);



// More info toggle
var button = document.getElementById('how');
var moreInfo = document.getElementById('more-info');

button.addEventListener('click', function() {
    moreInfo.style.display = 'block'; // Show the more-info div
    button.style.display = 'none';    // Hide the button
});